<?php
/**
 * @file
 * Admin functions for RADIUS client
 */

/**
 * Page handler for admin settings
 */
function radius_client_admin_settings() {
  $form = drupal_get_form('radius_client_admin_server_settings');
  return $form;
}

/**
 * Radius Server Administration Form
 */
function radius_client_admin_server_settings($form, &$form_state) {
  $server1 = variable_get('radius_client_server1', array(
    'address' => '127.0.0.1',
    'port' => '1812',
    'secret' => '',
    'timeout' => '5',
    'maxretries' => '3',
  ));
  $server2 = variable_get('radius_client_server2', array(
    'address' => '',
    'port' => '',
    'secret' => '',
    'timeout' => '',
    'maxretries' => '',
  ));

  $form['radius_client_server1'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#title' => t('Primary Server'),
    '#tree' => TRUE,
  );
  $form['radius_client_server1']['address'] = array(
    '#type' => 'textfield',
    '#title' => t('Address'),
    '#default_value' => $server1['address'],
    '#required' => TRUE,
  );
  $form['radius_client_server1']['port'] = array(
    '#type' => 'textfield',
    '#title' => t('Authentication Port'),
    '#default_value' => $server1['port'],
    '#required' => TRUE,
  );
  $form['radius_client_server1']['secret'] = array(
    '#type' => 'textfield',
    '#title' => t('Secret'),
    '#default_value' => $server1['secret'],
    '#required' => TRUE,
  );
  $form['radius_client_server1']['timeout'] = array(
    '#type' => 'textfield',
    '#title' => t('Timeout'),
    '#default_value' => $server1['timeout'],
    '#required' => TRUE,
  );
  $form['radius_client_server1']['maxretries'] = array(
    '#type' => 'textfield',
    '#title' => t('Max retries'),
    '#default_value' => $server1['maxretries'],
    '#required' => TRUE,
  );
  $form['radius_client_server2'] = array(
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#title' => t('Secondary Server'),
    '#tree' => TRUE,
  );
  $form['radius_client_server2']['address'] = array(
    '#type' => 'textfield',
    '#title' => t('Address'),
    '#default_value' => $server2['address'],
  );
  $form['radius_client_server2']['port'] = array(
    '#type' => 'textfield',
    '#title' => t('Authentication Port'),
    '#default_value' => $server2['port'],
  );
  $form['radius_client_server2']['secret'] = array(
    '#type' => 'textfield',
    '#title' => t('Secret'),
    '#default_value' => $server2['secret'],
  );
  $form['radius_client_server2']['timeout'] = array(
    '#type' => 'textfield',
    '#title' => t('Timeout'),
    '#default_value' => $server2['timeout'],
  );
  $form['radius_client_server2']['maxretries'] = array(
    '#type' => 'textfield',
    '#title' => t('Max retries'),
    '#default_value' => $server2['maxretries'],
  );
  return system_settings_form($form);
}

/**
 * Implements hook_form_validate().
 */
function radius_client_admin_server_settings_validate($form, &$form_state) {
  if (!ctype_digit($form_state['values']['radius_client_server1']['port'])) {
    form_set_error('radius_client_server1][port', t('Server port must be numeric'));
  }
  if (!ctype_digit($form_state['values']['radius_client_server1']['timeout'])) {
    form_set_error('radius_client_server1][timeout', t('Timeout must be numeric'));
  }
  if (!ctype_digit($form_state['values']['radius_client_server1']['maxretries'])) {
    form_set_error('radius_client_server1][timeout', t('Maximum Retries must be numeric'));
  }
  if ($form_state['values']['radius_client_server2']['port'] != '' && !ctype_digit($form_state['values']['radius_client_server2']['port'])) {
    form_set_error('radius_client_server1][port', t('Server port must be numeric'));
  }
  if ($form_state['values']['radius_client_server2']['timeout'] != '' && !ctype_digit($form_state['values']['radius_client_server2']['timeout'])) {
    form_set_error('radius_client_server1][timeout', t('Timeout must be numeric'));
  }
  if ($form_state['values']['radius_client_server2']['maxretries'] != '' && !ctype_digit($form_state['values']['radius_client_server2']['maxretries'])) {
    form_set_error('radius_client_server1][timeout', t('Maximum Retries must be numeric'));
  }
}
